@@ -15,23 +15,28 @@ from sqlalchemy import select, asc
 from sqlalchemy.dialects import postgresql
 from twisted.internet import task, reactor, defer
 from twisted.internet.defer import inlineCallbacks, Deferred, DeferredSemaphore
-from vortex.DeferUtil import deferToThreadWrapWithLogger, vortexLogFailure, \
-    nonConcurrentMethod
+from vortex.DeferUtil import (
+    deferToThreadWrapWithLogger,
+    vortexLogFailure,
+    nonConcurrentMethod,
+)
 from vortex.Payload import Payload
 
-from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusNotifierABC import \
-    ACIProcessorStatusNotifierABC
-from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import \
-    ACIProcessorQueueTupleABC
+from peek_abstract_chunked_index.private.server.controller.ACIProcessorStatusNotifierABC import (
+    ACIProcessorStatusNotifierABC,
+)
+from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import (
+    ACIProcessorQueueTupleABC,
+)
 from peek_plugin_base.storage.RunPyInPg import runPyInPg
 
-ACIProcessorQueueBlockItem = namedtuple("ACIProcessorQueueBlockItem",
-                                        ("queueIds", "itemsEncodedPayload",
-                                         "itemUniqueIds"))
+ACIProcessorQueueBlockItem = namedtuple(
+    "ACIProcessorQueueBlockItem", ("queueIds", "itemsEncodedPayload", "itemUniqueIds")
+)
 
 
 class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
-    """ Chunked Index Processor - Queue Controller
+    """Chunked Index Processor - Queue Controller
 
     Process the database queue and send chunks of data to the workers
     to process.
@@ -46,6 +51,7 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         _QueueTableDeclarative = LiveDbRawValueQueueTuple
 
     """
+
     MAX_CPU_PERCENTAGE = 80.00
 
     QUEUE_ITEMS_PER_TASK: int = None  # Example 500
@@ -68,16 +74,22 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
     # Use at most 2 database connections at a time for vacuuming
     __vacuumSemaphore = DeferredSemaphore(2)
 
-    def __init__(self, ormSessionCreator,
-                 processorStatusNotifier: ACIProcessorStatusNotifierABC,
-                 isProcessorEnabledCallable: Callable = None):
+    def __init__(
+        self,
+        ormSessionCreator,
+        processorStatusNotifier: ACIProcessorStatusNotifierABC,
+        isProcessorEnabledCallable: Callable = None,
+    ):
         self._dbSessionCreator = ormSessionCreator
-        self._processorStatusNotifier: ACIProcessorStatusNotifierABC = processorStatusNotifier
+        self._processorStatusNotifier: ACIProcessorStatusNotifierABC = (
+            processorStatusNotifier
+        )
         self._isProcessorEnabledCallable = isProcessorEnabledCallable
 
         self._pollLoopingCall = task.LoopingCall(self._poll)
-        self._nextVacuumTime = datetime.now(pytz.utc) \
-                               + self._randomiseTimeDelta(self.VACUUM_PERIOD_SECONDS)
+        self._nextVacuumTime = datetime.now(pytz.utc) + self._randomiseTimeDelta(
+            self.VACUUM_PERIOD_SECONDS
+        )
         self._queueCount = 0
 
         self._queueIdsInBuffer = set()
@@ -96,8 +108,9 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         assert self.WORKER_TASK_TIMEOUT, "ACI, WORKER_TASK_TIMEOUT is missing"
         assert self._logger, "ACI, _logger is missing"
         assert self._QueueDeclarative, "ACI, _QueueDeclarative is missing"
-        assert self.DEDUPE_LOOK_AHEAD_MIN_ROWS, \
-            "ACI, DEDUPE_LOOK_AHEAD_MIN_ROWS is missing"
+        assert (
+            self.DEDUPE_LOOK_AHEAD_MIN_ROWS
+        ), "ACI, DEDUPE_LOOK_AHEAD_MIN_ROWS is missing"
         assert self._VacuumDeclaratives, "ACI, _VacuumDeclaratives is missing"
         assert self.VACUUM_PERIOD_SECONDS, "ACI, VACUUM_PERIOD_SECONDS is missing"
 
@@ -203,9 +216,11 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             results = yield d
             yield self._processWorkerResults(results)
 
-            self._logger.debug("Processed %s items, Time Taken = %s",
-                               len(block.itemUniqueIds),
-                               datetime.now(pytz.utc) - startTime)
+            self._logger.debug(
+                "Processed %s items, Time Taken = %s",
+                len(block.itemUniqueIds),
+                datetime.now(pytz.utc) - startTime,
+            )
 
             # Success, Remove the chunks from the in-progress queue
             self._queueCount -= 1
@@ -213,7 +228,10 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             self._queueIdsInBuffer -= set(block.queueIds)
 
             # If the queue processor was paused for this chunk then resume it.
-            if self._pausedForDuplicate and self._pausedForDuplicate & block.itemUniqueIds:
+            if (
+                self._pausedForDuplicate
+                and self._pausedForDuplicate & block.itemUniqueIds
+            ):
                 self._pausedForDuplicate = None
 
             # Notify the status controller
@@ -240,17 +258,17 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         Example code:
 
         def _sendToWorker(self, block: _BlockItem) -> Deferred:
-            from peek_plugin_livedb._private.worker.tasks.LiveDbItemUpdateTask import \
-                updateValues
+            from peek_plugin_example._private.worker.tasks.ItemUpdateTask import \
+                itemUpdateTask
 
             # Return the deferred, this is important
-            return updateValues.delay(block.queueIds, block.itemsEncodedPayload)
+            return itemUpdateTask.delay(block.queueIds, block.itemsEncodedPayload)
 
         """
 
     @abstractmethod
     def _processWorkerResults(self, results):
-        """ Process Worker Results
+        """Process Worker Results
 
         This method allows the inherting class to do something with the worker results.
 
@@ -265,17 +283,21 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
     @inlineCallbacks
     def _fetchBlocks(self) -> List[ACIProcessorQueueBlockItem]:
 
-        dedupSql = self._dedupeQueueSql(self._lastFetchedId,
-                                        self.DEDUPE_LOOK_AHEAD_MIN_ROWS) \
-            if self._lastFetchedId else None
+        dedupSql = (
+            self._dedupeQueueSql(self._lastFetchedId, self.DEDUPE_LOOK_AHEAD_MIN_ROWS)
+            if self._lastFetchedId
+            else None
+        )
 
-        rawBlocks = yield runPyInPg(self._logger,
-                                    self._dbSessionCreator,
-                                    self._fetchBlocksInPg,
-                                    None,
-                                    list(self._queueIdsInBuffer),
-                                    self._queueCount,
-                                    dedupSql)
+        rawBlocks = yield runPyInPg(
+            self._logger,
+            self._dbSessionCreator,
+            self._fetchBlocksInPg,
+            None,
+            list(self._queueIdsInBuffer),
+            self._queueCount,
+            dedupSql,
+        )
 
         blocks = []
         for raw in rawBlocks:
@@ -289,10 +311,9 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         return blocks
 
     @classmethod
-    def _fetchBlocksInPg(cls, plpy,
-                         queueIdsInBuffer: List[int],
-                         queueCount: int,
-                         dedupSql: Optional[str]) -> List[ACIProcessorQueueBlockItem]:
+    def _fetchBlocksInPg(
+        cls, plpy, queueIdsInBuffer: List[int], queueCount: int, dedupSql: Optional[str]
+    ) -> List[ACIProcessorQueueBlockItem]:
         # ---------------
         # Deduplicate the queue before we fetch more
         if dedupSql:
@@ -311,12 +332,13 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
         # This is sorted with the newest queue item first for "USE LAST ITEM"
         # deduplication
-        sql = select([queueTable]) \
-            .order_by(asc(queueTable.c.id)) \
-            .limit(toGrab)
+        sql = select([queueTable]).order_by(asc(queueTable.c.id)).limit(toGrab)
 
-        sqlQry = str(sql.compile(dialect=postgresql.dialect(),
-                                 compile_kwargs={"literal_binds": True}))
+        sqlQry = str(
+            sql.compile(
+                dialect=postgresql.dialect(), compile_kwargs={"literal_binds": True}
+            )
+        )
 
         # ---------------
         # Turn a row["val"] into a row.val
@@ -357,7 +379,7 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
             queueIds = []
             itemUniqueIds = []
             items = []
-            for item in queueItems[start: start + cls.QUEUE_ITEMS_PER_TASK]:
+            for item in queueItems[start : start + cls.QUEUE_ITEMS_PER_TASK]:
                 queueIds.append(item.id)
                 if item.ckiUniqueKey in addedUniqueKeys:
                     continue
@@ -368,9 +390,7 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
             itemsEncodedPayload = Payload(tuples=[items, queueIds]).toEncodedPayload()
 
-            queueBlocks.append(
-                (queueIds, itemsEncodedPayload.decode(), itemUniqueIds)
-            )
+            queueBlocks.append((queueIds, itemsEncodedPayload.decode(), itemUniqueIds))
 
         # Put the oldest queue blocks back at the start
         queueBlocks = list(reversed(queueBlocks))
@@ -379,7 +399,7 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
     @abstractmethod
     def _dedupeQueueSql(self, lastFetchedId: int, dedupeLimit: int):
-        """ Deduplicate Queue SQL
+        """Deduplicate Queue SQL
 
         This method will look ahead and deduplicate the queue before this class loads
         up the data.
@@ -425,14 +445,16 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
         if datetime.now(pytz.utc) < self._nextVacuumTime:
             return defer.succeed(True)
 
-        self._nextVacuumTime = datetime.now(pytz.utc) \
-                               + self._randomiseTimeDelta(self.VACUUM_PERIOD_SECONDS)
+        self._nextVacuumTime = datetime.now(pytz.utc) + self._randomiseTimeDelta(
+            self.VACUUM_PERIOD_SECONDS
+        )
 
-        return self.__vacuumSemaphore.run(deferToThreadWrapWithLogger(self._logger)
-                                          (self.__vacuumTablesWrapped))
+        return self.__vacuumSemaphore.run(
+            deferToThreadWrapWithLogger(self._logger)(self.__vacuumTablesWrapped)
+        )
 
     def __vacuumTablesWrapped(self):
-        """ Vacuum Tables
+        """Vacuum Tables
 
         This method will vacuum the tables in Post
 
@@ -457,7 +479,7 @@ class ACIProcessorQueueControllerABC(metaclass=ABCMeta):
 
                 while len(rawConn.notices) < 2:
                     sleep(2.0)
-                self._logger.debug(rawConn.notices[1].replace('\n', ', '))
+                self._logger.debug(rawConn.notices[1].replace("\n", ", "))
 
             except Exception as e:
                 self._logger.error("Vacuum failed for Table %s.%s", schema, tableName)
